# lambda-utility
[![Python](https://img.shields.io/badge/python-v3.9-blue.svg?&logo=python&style=flat)](https://docs.python.org/3.9/)
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)

AWS Lambda에서 자주 사용하는 기능 구현

## Installation
Python 3.7 +
```bash
$ pip install lambda-utility
```
